#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import select
import sys
import pybonjour
from socket import gethostbyname

regtype  = '_irkit._tcp'
timeout  = 1
resolved = []
irkits = []

def resolve_callback(sdRef, flags, interfaceIndex, errorCode, fullname,
                     hosttarget, port, txtRecord):
    if errorCode == pybonjour.kDNSServiceErr_NoError:
        irkits.append((hosttarget, port))
        resolved.append(True)


def browse_callback(sdRef, flags, interfaceIndex, errorCode, serviceName,
                    regtype, replyDomain):
    if errorCode != pybonjour.kDNSServiceErr_NoError:
        return
    if not (flags & pybonjour.kDNSServiceFlagsAdd):
        print('Service removed', file=sys.stderr)
        return

    with pybonjour.DNSServiceResolve(0,
                                     interfaceIndex,
                                     serviceName,
                                     regtype,
                                     replyDomain,
                                     resolve_callback) as resolve_sdRef:
        while not resolved:
            ready = select.select([resolve_sdRef], [], [], timeout)
            if resolve_sdRef not in ready[0]:
                print('Resolve timed out', file=sys.stderr)
                break
            pybonjour.DNSServiceProcessResult(resolve_sdRef)
        else:
            resolved.pop()


def resolve_irkits():
    with pybonjour.DNSServiceBrowse(regtype = regtype,
                                    callBack = browse_callback) as browse_sdRef:
        while True:
            ready = select.select([browse_sdRef], [], [], timeout)
            if browse_sdRef in ready[0]:
                pybonjour.DNSServiceProcessResult(browse_sdRef)
            else:
                return irkits

if __name__ == '__main__':
    for irkit in resolve_irkits():
        print('hosttarget={0}\nIPaddress={1}\nport={2}'.format(irkit[0], gethostbyname(irkit[0]), irkit[1]))

